@@ -197,12 +197,20 @@ class ScaffoldGraph(nx.DiGraph, ABC):
 
         """
         desc, progress = self.__class__.__name__, progress is False
+
+        #print('CONSTRUCT');
+        count_mol = 0;
         for molecule in tqdm(
             molecules, disable=progress, desc=desc,
             miniters=1, dynamic_ncols=True,
         ):
-            #print('processing mol');
+            #print('Processing mol ', count_mol);
             #print(MolToMolBlock(molecule, kekulize=False));
+           #if count == 15:
+           #   count = count + 1;
+           #   continue;
+
+            count_mol = count_mol + 1;
             
             if molecule is None:
                 continue
@@ -211,7 +219,7 @@ class ScaffoldGraph(nx.DiGraph, ABC):
             molQTest = MolFromSmarts("[#6,#7,#8;#16,a]")
             arom_atom_indices_ = molecule.GetSubstructMatches(molQTest)#.map((s) => s[0]);
             arom_atom_indices = sorted(list(map(lambda x: x[0], arom_atom_indices_)))
-            
+            #print('Processing mol 1', count_mol);
             
             #rings = [set(x) for x in GetSymmSSSR(molecule)]
             rings_aroma = [];
@@ -254,16 +262,20 @@ class ScaffoldGraph(nx.DiGraph, ABC):
 
             init_molecule_name(molecule)
             #print('nofrings', CalcNumRings(molecule))
+            #print('Processing mol 3', count_mol);
+            
             if CalcNumRings(molecule) > ring_cutoff:
                 name = molecule.GetProp('_Name')
                 logger.warning(f'Molecule {name} filtered (> {ring_cutoff} rings)')
                 self.graph['num_filtered'] = self.graph.get('num_filtered', 0) + 1
                 continue
+            #print('Processing mol 4', count_mol);
             scaffold = self._initialize_scaffold(molecule, init_args)
             #print(MolToMolBlock(scaffold.mol, kekulize=False));
-
+            #print('Processing mol 5', count_mol);
             if scaffold is not None:
                 self._hierarchy_constructor(scaffold)
+            
 
     def _initialize_scaffold(self, molecule, init_args):
         """Initialize the top-level scaffold for a molecule.
@@ -317,16 +329,16 @@ class ScaffoldGraph(nx.DiGraph, ABC):
 
         #molAMolBlk = MolToMolBlock(scaffold_rdmol, kekulize=False);
         #print(molAMolBlk)
-        
+       
         scaffold = Scaffold(scaffold_rdmol)
         #molAMolBlk = MolToMolBlock(scaffold.mol, kekulize=False);
         #print(molAMolBlk)
-
         #print(scaffold.mol)
-
+        #print('Processing mol 4a');
         annotation = None
         if init_args.get('annotate') is True:
             annotation = get_annotated_murcko_scaffold(molecule, scaffold_rdmol, False)
+        #print('Processing mol 4b');
         self.add_scaffold_node(scaffold)
         self.add_molecule_node(molecule)
         self.add_molecule_edge(molecule, scaffold, annotation=annotation)
